@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python33
 # This file is part of Xpra.
 # Copyright (C) 2012 Serviware (Arthur Huillet, <ahuillet@serviware.com>)
 # Copyright (C) 2012-2019 Antoine Martin <antoine@xpra.org>
@@ -12,7 +12,6 @@ from xpra.util import envbool, envint, csv
 from xpra.os_util import POSIX, OSX, bytestostr
 from xpra.log import Logger, CaptureHandler
 from xpra.client.gl.gl_drivers import WHITELIST, GREYLIST, VERSION_REQ, BLACKLIST, OpenGLFatalError
-from xpra.sound.gstreamer_util import force_enabled
 
 log = Logger("opengl")
 
@@ -130,7 +129,7 @@ def check_PyOpenGL_support(force_enable) -> dict:
         from OpenGL.GL import GL_VERSION, GL_EXTENSIONS
         from OpenGL.GL import glGetString, glGetIntegerv
         gl_version_str = glGetString(GL_VERSION)
-        if gl_version_str is None and not force_enabled:
+        if gl_version_str is None and not force_enable:
             raise_fatal_error("OpenGL version is missing - cannot continue")
             return props
         #b'4.6.0 NVIDIA 440.59' -> ['4', '6', '0 NVIDIA...']
@@ -147,7 +146,7 @@ def check_PyOpenGL_support(force_enable) -> dict:
             props["opengl"] = gl_major, gl_minor
             MIN_VERSION = (1,1)
             if (gl_major, gl_minor) < MIN_VERSION:
-                if not force_enabled:
+                if not force_enable:
                     raise_fatal_error("OpenGL output requires version %s or greater, not %s.%s" %
                                   (".".join([str(x) for x in MIN_VERSION]), gl_major, gl_minor))
                     return props
@@ -264,10 +263,8 @@ def check_PyOpenGL_support(force_enable) -> dict:
                 log.warn("Warning: %s '%s' is blacklisted!", *blacklisted)
                 log.warn(" force enabled by option")
             else:
-                if force_enable:
-                    log.warn("%s '%s' is blacklisted!" % (blacklisted))
-                else:
-                    raise_fatal_error("%s '%s' is blacklisted!" % (blacklisted))
+                log.warn("%s '%s' is blacklisted!" % (blacklisted))
+                raise_fatal_error("%s '%s' is blacklisted!" % (blacklisted))
         safe = bool(whitelisted) or not bool(blacklisted)
         if greylisted and not whitelisted:
             log.warn("Warning: %s '%s' is greylisted,", *greylisted)
